@@ -3,6 +3,7 @@ from .._compat import Literal
 from . import base
 from .. import tl
 import numpy as np
+import matplotlib.pyplot as plt
 
 
 def alpha_diversity(
@@ -12,15 +13,15 @@ def alpha_diversity(
     target_col: str = "clonotype",
     vistype: Literal["bar"] = "bar",
     **kwargs
-) -> None:
+) -> plt.Axes:
     """Plot the alpha diversity per group. 
 
-    Calls :meth:`tl.alpha_diversity` on-the-fly. 
+    Calls :func:`scirpy.tl.alpha_diversity`. 
 
     Parameters
     ----------
     adata
-        Annotated data matrix. Will execute `tl.alpha_diversity` on-the-fly.
+        Annotated data matrix. Will execute :func:`scirpy.tl.alpha_diversity` on-the-fly.
     groupby
         Column of `obs` by which the grouping will be performed
     target_col
@@ -28,7 +29,7 @@ def alpha_diversity(
     vistype
         Visualization type. Currently only 'bar' is supported. 
     **kwargs
-        Additional parameters passed to :meth:`pl.base.bar`
+        Additional parameters passed to :func:`scirpy.pl.base.bar`
     """
     diversity = tl.alpha_diversity(adata, groupby, target_col=target_col, inplace=False)
     default_style_kws = {
