@@ -6,10 +6,9 @@ import seaborn as sns
 from scipy.spatial import distance as sc_distance
 from scipy.cluster import hierarchy as sc_hierarchy
 from typing import Union, Sequence
-from .._util import _is_na
 from .. import tl
-from ._styling import style_axes, DEFAULT_FIG_KWS, _init_ax
-from ._base import ol_scatter
+from .styling import _init_ax, _get_colors
+from .base import ol_scatter
 
 
 def repertoire_overlap(
@@ -28,6 +27,9 @@ def repertoire_overlap(
 ) -> plt.Axes:
     """Visualizes overlap betwen a pair of samples on a scatter plot or
     all samples on a heatmap or draws a dendrogram of samples only.
+
+    .. warning:: 
+        This is an experimental function that will likely change in the future. 
     
     Parameters
     ----------
@@ -72,6 +74,7 @@ def repertoire_overlap(
             overlap_measure=overlap_measure,
             overlap_threshold=overlap_threshold,
             fraction=fraction,
+            added_key=added_key,
         )
     df = adata.uns[added_key]["weighted"]
 
@@ -86,22 +89,14 @@ def repertoire_overlap(
                     .agg("size")
                     .reset_index()
                 )
+                colordict = _get_colors(adata, lbl)
                 label_levels = labels[lbl].unique()
-                label_pal = sns.cubehelix_palette(
-                    label_levels.size,
-                    light=0.7,
-                    dark=0.3,
-                    reverse=True,
-                    start=2.5,
-                    rot=-2,
-                )
-                colordict = dict(zip(label_levels, label_pal))
                 for e in label_levels:
                     leg_colors.append((lbl + ": " + e, colordict[e]))
                 labels[lbl] = labels[lbl].astype(str)
                 labels[lbl] = labels.loc[:, lbl].map(colordict)
-                clust_colors.append(labels[lbl])
                 labels = labels.loc[:, [groupby, lbl]].set_index(groupby)
+                clust_colors.append(labels[lbl])
                 colordict = labels.to_dict()
                 colordict = colordict[lbl]
 
@@ -128,12 +123,19 @@ def repertoire_overlap(
             if heatmap_cats is None:
                 ax = sns.clustermap(1 - distM, col_linkage=linkage, row_cluster=False)
             else:
+                _clust_colors, annotation_labels = [], []
+                for cl in clust_colors:
+                    _clust_colors.append(cl.loc[distM.index.values])
+                    annotation_labels.append(cl.name)
+                clust_colors = _clust_colors
                 ax = sns.clustermap(
                     1 - distM,
                     col_linkage=linkage,
                     row_cluster=False,
                     row_colors=clust_colors,
                 )
+                for i, a in enumerate(annotation_labels):
+                    ax.ax_row_colors.text(i + 0.3, -0.4, a, rotation=90)
                 lax = ax.ax_row_dendrogram
                 for e, c in leg_colors:
                     lax.bar(0, 0, color=c, label=e, linewidth=0)
@@ -168,9 +170,9 @@ def repertoire_overlap(
                 # Create text for default labels
                 p_a, p_b = pair_to_plot
                 default_style_kws = {
-                    "title": "Repertoire overlap between " + p_a + "and" + p_b,
-                    "xlab": "Conotype size in " + p_a,
-                    "ylab": "Conotype size in " + p_b,
+                    "title": "Repertoire overlap between " + p_a + " and " + p_b,
+                    "xlab": "Clonotype size in " + p_a,
+                    "ylab": "Clonotype size in " + p_b,
                 }
                 if "style_kws" in kwargs:
                     default_style_kws.update(kwargs["style_kws"])
