@@ -1,9 +1,10 @@
 from anndata import AnnData
-from typing import Union
+from typing import Union, Tuple
 from scipy.spatial import distance as sc_distance
 from scipy.cluster import hierarchy as sc_hierarchy
 import pandas as pd
-from .._util import _is_na, _normalize_counts
+import numpy as np
+from ..util import _is_na, _normalize_counts
 
 
 def repertoire_overlap(
@@ -16,10 +17,14 @@ def repertoire_overlap(
     fraction: Union[None, str, bool] = None,
     inplace: bool = True,
     added_key: str = "repertoire_overlap",
-) -> pd.DataFrame:
+) -> Union[None, Tuple[pd.DataFrame, np.ndarray, np.ndarray]]:
     """Compute distance between cell groups based on clonotype overlap.
 
-    Adds parwise overlaps, distance matrix and linkage to `uns`
+    Adds parwise overlaps, distance matrix and linkage to `uns`.
+
+    .. warning::
+
+        This function is experimental and is likely to change in the future. 
     
     Parameters
     ----------
@@ -48,7 +53,7 @@ def repertoire_overlap(
 
     Returns
     -------
-    A DataFrame used by the pairwise scatterplot (but also adds a distance matrix and linkage to `uns`). 
+    A DataFrame used by the pairwise scatterplot, distance matrix and linkage. 
     """
 
     # Remove NA rows
