@@ -3,7 +3,7 @@ from typing import Callable, Union, Collection
 import numpy as np
 import pandas as pd
 from ._group_abundance import _group_abundance
-from .._util import _is_na
+from ..util import _is_na
 
 
 def spectratype(
@@ -14,7 +14,7 @@ def spectratype(
     combine_fun: Callable = np.sum,
     fraction: Union[None, str, bool] = None,
 ) -> pd.DataFrame:
-    """Show the distribution of CDR3 region lengths. 
+    """Summarizes the distribution of :term:`CDR3` region lengths. 
 
     Ignores NaN values. 
     
