@@ -1,7 +1,8 @@
-from scirpy import read_10x_vdj, read_tracer
-from scirpy._util import _is_na, _is_false
+from scirpy.io import read_10x_vdj, read_tracer, read_airr
+from scirpy.util import _is_na, _is_false
 import numpy as np
 import pytest
+import pandas.testing as pdt
 
 
 def test_read_10x_example():
@@ -97,3 +98,41 @@ def test_read_tracer():
     assert cell2["TRA_1_cdr3"] == "ALSEAEGGSEKLV"
     assert cell2["TRB_1_cdr3"] == "ASSYNRGPGGTQY"
     assert cell2["TRB_1_j_gene"] == "TRBJ2-5"
+
+
+def test_read_airr():
+    # Test that reading the files one-by-one or at once yields the same results
+    anndata_tra = read_airr("tests/data/airr/rearrangement_tra.tsv")
+    anndata_trb = read_airr("tests/data/airr/rearrangement_trb.tsv")
+    anndata = read_airr(
+        [
+            "tests/data/airr/rearrangement_tra.tsv",
+            "tests/data/airr/rearrangement_trb.tsv",
+        ]
+    )
+    tra_cols = [
+        "TRA_1_cdr3",
+        "TRA_1_cdr3_nt",
+        "TRA_1_v_gene",
+        "TRA_1_d_gene",
+        "TRA_1_j_gene",
+        "TRA_1_c_gene",
+        "TRA_1_expr",
+    ]
+    trb_cols = [x.replace("TRA", "TRB") for x in tra_cols]
+    pdt.assert_frame_equal(anndata.obs[tra_cols], anndata_tra.obs[tra_cols])
+    pdt.assert_frame_equal(anndata.obs[trb_cols], anndata_trb.obs[trb_cols])
+
+    # test some fundamental values
+    assert "cell1" in anndata.obs_names and "cell2" in anndata.obs_names
+    assert anndata.obs.shape[0] == 3
+
+    cell1 = anndata.obs.loc["cell1", :]
+    cell2 = anndata.obs.loc["cell2", :]
+
+    assert cell1.name == "cell1"
+    assert cell1["TRA_1_cdr3"] == "CTRPKWESPMVDAFDIW"
+    assert cell1["TRB_2_cdr3"] == "CQQYDNLQITF"
+    assert cell1["TRB_1_cdr3"] == "CQQYYHTPYSF"
+
+    assert cell2.name == "cell2"
